@@ -1,7 +1,4 @@
 from datetime import date
-import json
-import pandas
-from quick_resto_API.quick_resto_objects.quick_resto_object import QuickRestoObject, QuickRestoObjectEncoder
 
 from quick_resto_API.quick_resto_api import QuickRestoApi
 from quick_resto_API.quick_resto_objects.modules.crm.account_type import AccountType
