@@ -50,9 +50,10 @@ class CompanyInfo(QuickRestoObject):
     def short_name(self) -> str:
         return self._short_name
 
-    def __init__(self, account: str, address: str, bankId: str, bankName: str, correspondentAccount: str,
-                 deliveryAddress: str, deleted: bool, innCode: str, kppCode: str, name: str, okpoCode: str,
-                 shortName: str, **kwargs):
+    def __init__(self, account: str = None, address: str = None, bankId: str = None, bankName: str = None, 
+                correspondentAccount: str = None, deliveryAddress: str = None, deleted: bool = None, innCode: str = None, 
+                kppCode: str = None, name: str = None, okpoCode: str = None,shortName: str = None, **kwargs):
+
         class_name = "ru.edgex.quickresto.modules.core.company.CompanyInfo"
 
         super().__init__(class_name=class_name, **kwargs)
