@@ -29,19 +29,15 @@ StrToCrmCustomerSex = {
 
 
 def convert_str_to_crm_customer_type(crm_customer_type: str) -> CrmCustomerType:
-    crm_customer_type = crm_customer_type.upper()
-
-    if crm_customer_type in CrmCustomerType.__members__.keys():
-        return CrmCustomerType.__members__[crm_customer_type]
+    if crm_customer_type in StrToCrmCustomerType.keys():
+        return StrToCrmCustomerType[crm_customer_type]
 
     return CrmCustomerType.NONE
 
 
 def convert_str_to_crm_customer_sex(crm_customer_sex: str) -> CrmCustomerSex:
-    crm_customer_sex = crm_customer_sex.upper()
-
-    if crm_customer_sex in CrmCustomerSex.__members__.keys():
-        return CrmCustomerSex.__members__[crm_customer_sex]
+    if crm_customer_sex in StrToCrmCustomerSex.keys():
+        return StrToCrmCustomerSex[crm_customer_sex]
 
     return CrmCustomerSex.NONE
 
@@ -122,7 +118,7 @@ class CrmCustomer(QuickRestoObject):
 
         self._customer_type: CrmCustomerType = convert_str_to_crm_customer_type(type)
 
-        if customerGroup is None: 
+        if customerGroup is not None: 
             self._group: Group = Group(**customerGroup)
         else:
             self._group = None
