@@ -16,7 +16,7 @@ class TimeRange(QuickRestoObject):
     def end(self) -> str:
         return self._end
 
-    def __init__(self, start: str, end: str):
+    def __init__(self, start: str = None, end: str = None):
         self._start: str = start
         self._end: str = end
 
