@@ -59,9 +59,13 @@ class DishCategory(QuickRestoObject):
     @property
     def store_item_tag(self) -> StoreItemTag:
         return self._store_item_tag
+    
+    @property
+    def parent_item(self) -> dict:
+        return self._parent_item
 
     def __init__(self, itemTitle: str = None, name: str = None, displayOnTerminal: bool = None, color: str = None,
-                 sellingType: str = None,
+                 sellingType: str = None, parentItem: dict = None,
                  measureUnit: dict = None, dishSales=None, storeItemTag=None, **kwargs):
         class_name: str = "ru.edgex.quickresto.modules.warehouse.nomenclature.dish.DishCategory"
 
@@ -70,6 +74,7 @@ class DishCategory(QuickRestoObject):
         self._name: str = name
         self._color: str = color
         self._display_on_terminal: bool = displayOnTerminal
+        self._parent_item = parentItem
 
         if measureUnit is not None: 
             self._measure_unit: MeasureUnit = MeasureUnit(**measureUnit)
